Overview
^^^^^^^^

Why use Dataspectra?
====================

Traditionally, creating an interactive data visualization 
on the web required multiple components.

1. Your data 
2. An idea of how the web page looks. 
3. Uploading your data to a web server. 
4. Code to access your data. 
5. Code to plot the data. 
6. Code to arrange the plots, text, and web design. 
7. Access to a web-server that will handle the user-interactions. 

Dataspectra makes this process easier by doing all of the
coding and uploading processes for you. So now all you need
are the following:

1. Your data 
2. An idea of how the web page looks. 
3. Dataspectra

You can think of it like the Squarespace for web-visualization of data.  

How does Dataspectra work?
==========================

To create a dataspectra page, there are three main parts. 

Step 1: Gather your data and design your web page. 

Step 2: Create a Google Cloud account. (The web-serving is handled by
Google Cloud Platform, which provides a nearly-free service for most projects.)

Step 3: Run Dataspectra with information from Step 1 and Step 2. 

About the documentation
=======================

Steps 1, 2, and 3 will demonstrate how dataspectra works in a tutorial format. 

To simply test whether dataspectra works, you can skip the latter half of
Step 1 and use the included tutorial parameter file. 
You will need to still do Steps 2 and 3. 

"Parameters" describes the full set of available parameters for customization. 

"Advanced" describes how to perform more advanced functions like setting up passwords, 
adding your own domain, accessing meta files, or fixing aspect ratios.  

"More examples" describes more figure types that can be created. 

"For developers" describes how to get involved with this developing dataspectra further.

